==> nemo_toolkit-0.10.0b9.tar.gz: nemo_toolkit-0.10.0b9/nemo/collections/nlp/nm/data_layers/__init__.py <==
# =============================================================================
# Copyright 2020 NVIDIA. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# =============================================================================

from nemo.collections.nlp.nm.data_layers.glue_benchmark_datalayer import *
from nemo.collections.nlp.nm.data_layers.joint_intent_slot_datalayer import *
from nemo.collections.nlp.nm.data_layers.lm_bert_datalayer import *
from nemo.collections.nlp.nm.data_layers.lm_transformer_datalayer import *
from nemo.collections.nlp.nm.data_layers.machine_translation_datalayer import *
from nemo.collections.nlp.nm.data_layers.punctuation_capitalization_datalayer import *
from nemo.collections.nlp.nm.data_layers.qa_squad_datalayer import *
from nemo.collections.nlp.nm.data_layers.state_tracking_trade_datalayer import *
from nemo.collections.nlp.nm.data_layers.text_classification_datalayer import *
from nemo.collections.nlp.nm.data_layers.text_datalayer import *
from nemo.collections.nlp.nm.data_layers.token_classification_datalayer import *

==> nemo_toolkit-0.11.0b4.tar.gz: nemo_toolkit-0.11.0b4/nemo/collections/nlp/nm/data_layers/__init__.py <==
# =============================================================================
# Copyright 2020 NVIDIA. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# =============================================================================

from nemo.collections.nlp.nm.data_layers.bert_inference_datalayer import *
from nemo.collections.nlp.nm.data_layers.glue_benchmark_datalayer import *
from nemo.collections.nlp.nm.data_layers.joint_intent_slot_datalayer import *
from nemo.collections.nlp.nm.data_layers.lm_bert_datalayer import *
from nemo.collections.nlp.nm.data_layers.lm_transformer_datalayer import *
from nemo.collections.nlp.nm.data_layers.machine_translation_datalayer import *
from nemo.collections.nlp.nm.data_layers.punctuation_capitalization_datalayer import *
from nemo.collections.nlp.nm.data_layers.qa_squad_datalayer import *
from nemo.collections.nlp.nm.data_layers.state_tracking_sgd_datalayer import *
from nemo.collections.nlp.nm.data_layers.state_tracking_trade_datalayer import *
from nemo.collections.nlp.nm.data_layers.text_classification_datalayer import *
from nemo.collections.nlp.nm.data_layers.text_datalayer import *
from nemo.collections.nlp.nm.data_layers.token_classification_datalayer import *
